@@ -28,7 +28,7 @@
 # v2011-11-29 Paco Adaptierung auf Layout (feststehende Kopf- und
 #                  Fusszeile)
 # v2011-12-21 Paco Beim Update Kennwort fehlte im SQL-Select ein
-#                  Leerzeichen
+#                  Leerzeichen9
 # v2014-07-03 Paco Neue Installation im Zuge Projekt OPO CI_LOG5
 # v2014-07-04 Paco neue Email und neuer Link
 # v2014-07-21 Paco es werden nur Konstateneinträge berücksichtigt, deren
@@ -40,6 +40,7 @@
 # v2014-08-03 Paco Neuer Parameter IBNcanAddOPEntries mit dem eingestellt
 #                  werden kann, ob ein IBN auch OP-Punkte anlegen darf
 #                  oder nicht
+# v2014-11-19 Paco Fehler bei Passwortaenderung behoben
 ######################################################################
 ####  Variables that should be adapted if necessary
 ####------------------------------------------------------------------
@@ -97,7 +98,7 @@ $header = '<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01//EN">
     <body link="#0000FF" vlink="#0000FF">
     <div class="header"><img src="img/logo.jpg" width=114 height=48 border=0 alt="OPList">';
 
-$footer = '</div><div class="footer"><small>&copy; 2011 by <a href="http://software.glawar.at/oplist/" target="_blank">OPList</a> v1.9.530 (2014-08-03)</small></div></body></html>';
+$footer = '</div><div class="footer"><small>&copy; 2011 by <a href="http://software.glawar.at/oplist/" target="_blank">OPList</a> v1.11.574 (2014-11-19)</small></div></body></html>';
 
 
 session_start();
@@ -675,7 +676,7 @@ if (empty($_SESSION['OPUID']) || empty($_SESSION['OPGID'])) {
             "OPUEMAIL = '" . $_POST["OPUEMAIL"] . "', " .
             "OPULNAME = '" . $_POST["OPULNAME"] . "', " .
             $tempPwdString.
-            "OPUFNAME = '" . $_POST["OPUFNAME"] . "' " .
+            ", OPUFNAME = '" . $_POST["OPUFNAME"] . "' " .
             "WHERE OPUID = ".$_POST["OPUID"];
         debugIntoFile("Update-User-Select: <".$sQuery.">");
         #if ($debugSQL == 1) {
@@ -880,7 +881,7 @@ if (empty($_SESSION['OPUID']) || empty($_SESSION['OPGID'])) {
             $newFileName = "null";
         }
 
-        $sQuery = "INSERT INTO OPLIST_COMMENT (OPCID, OPUID, OPCTEXT, OPID, OPCPRIVATE, OPCFILENAME) VALUES (".$nextId.", ".$_SESSION['OPUID'].", '".$_POST["OPCTEXT"]."', ".$_POST["OPID"].", ".$OPCPRIVATE.", ".$newFileName.")";
+        $sQuery = "INSERT INTO OPLIST_COMMENT (OPCID, OPUID, OPCTEXT, OPID, OPCPRIVATE, OPCFILENAME) VALUES (".$nextId.", ".$_SESSION['OPUID'].", '".str_replace("'","''",$_POST["OPCTEXT"])."', ".$_POST["OPID"].", ".$OPCPRIVATE.", ".$newFileName.")";
         debugIntoFile("Insert-Kommentar-Select: <".$sQuery.">");
         #if ($debugSQL == 1) {
         #    echo "<p><b>Insert-Kommentar:</b>".$sQuery."</p>";
