@@ -4,7 +4,7 @@ if [ $# -eq 1 ]; then
     #rm oplist/oplist.tgz
     cd ..
     cd ..
-    tar cfvz oplist.tgz oplist/* --exclude='*.ini' --exclude='oplist_v*.tgz'
+    tar cfvz oplist.tgz oplist/* --exclude='*.ini' --exclude='oplist_v*.tgz' --exclude='oplist*.log'
     mv oplist.tgz oplist/make/oplist
     cd oplist/make
     tar cfvz oplist_v${1}.tgz oplist/*
